@@ -3,8 +3,8 @@
 != Error handling
 !
 ! Authors::   Eizi TOYODA, Yasuhiro MORIKAWA
-! Version::   $Id: dc_error.f90,v 1.17 2007/07/10 17:18:58 morikawa Exp $
-! Tag Name::  $Name: gt4f90io-20070711 $
+! Version::   $Id: dc_error.f90,v 1.19 2007/07/21 13:14:10 morikawa Exp $
+! Tag Name::  $Name: gt4f90io-20070720 $
 ! Copyright:: Copyright (C) GFD Dennou Club, 2000-2005. All rights reserved.
 ! License::   See COPYRIGHT[link:../../COPYRIGHT]
 !
@@ -360,7 +360,13 @@ module dc_error
   ! -410    :: [ <b>DC_ENOFILEWRITE</b> ]
   !            <b></b> :: file (<i>cause_c</i>) is not writable
   !
-  ! -411-499  :: <b>                     </b>
+  ! -411    :: [ <b>DC_ENEGATIVE          </b> ]
+  !            <b></b> :: negative value is invalid for (<i>cause_c</i>)
+  !
+  ! -412    :: [ <b>DC_EARGLACK          </b> ]
+  !            <b></b> :: lack of arguments (<i>cause_c</i>)
+  !
+  ! -413-499  :: <b>                     </b>
   !                <b></b> :: ( DC 桼ƥƥγĥΤͽ.
   !                           Reserved area for future extensions of DC utilities)
   !
@@ -456,6 +462,8 @@ module dc_error
   integer, parameter, public:: DC_ENOFILEEXIST   = -408
   integer, parameter, public:: DC_ENOFILEREAD    = -409
   integer, parameter, public:: DC_ENOFILEWRITE   = -410
+  integer, parameter, public:: DC_ENEGATIVE      = -411
+  integer, parameter, public:: DC_EARGLACK       = -412
 
   !
   ! -1000 ʲ: 桼
@@ -571,6 +579,10 @@ contains
       msg = " file (" // trim(cause_string) // ") is not readable"
     case(DC_ENOFILEWRITE)
       msg = " file (" // trim(cause_string) // ") is not writable"
+    case(DC_ENEGATIVE)
+      msg = ' negative value is invalid for (' // trim(cause_string) // ')'
+    case(DC_EARGLACK)
+      msg = ' lack of arguments (' // trim(cause_string) // ')'
       !
       ! -1000 ʲ: 桼
       ! -1000 or less: User-defined error
